@@ -31,6 +31,7 @@ Luke Arno can be found at http://lukearno.com/
 import urllib
 import cgi
 import mimetypes
+import Cookie
 from cStringIO import StringIO
 
 from wsgiref import headers, util
@@ -56,7 +57,7 @@ class URI(object):
             self.port += environ['SERVER_POST']
         self.script = environ.get('SCRIPT_NAME', '')
         self.path = environ.get('PATH_INFO', '')
-        self.query = environ.get('QUERY_STRING')
+        self.query = environ.get('QUERY_STRING', '')
 
     def __call__(self, path=None, with_qs=False):
         """Complete URI string with optional query string and path.
@@ -144,6 +145,8 @@ class Request(object):
             self._parse_form()
         elif attr == 'body' and not 'body' in self.__dict__:
             self._load_body()
+        elif attr == 'cookie' and not 'cookie' in self.__dict__:
+            self._load_cookie()
         return self.__dict__[attr]
 
     def _parse_query(self):
@@ -235,6 +238,11 @@ class Request(object):
         else:
             self.body = ""
 
+    def _load_cookie(self):
+        """Set self.cookie with a populated Cookie.SimpleCookie."""
+        self.cookie = Cookie.SimpleCookie()
+        self.cookie.load(self.environ.get('HTTP_COOKIE', ''))
+
     def redirect(self, location, permanent=True):
         """Set the location header and status."""
         self.res.headers['Location'] = location
@@ -303,6 +311,8 @@ if __name__ == '__main__':
 
     def foo(req):
         #req.res.body = 'Hello, World!'
+        sc = Cookie.SimpleCookie(); sc['mycookie'] = 'cookieval'
+        req.res.headers.add_header(*tuple(str(sc).split(': ', 1)))
         code.interact(local=locals(), banner="%s: %s" % (req.method, req.uri()))
         if req.uri.path.endswith('.rdr'):
             req.redirect('../proudhon.txt')
